@@ -129,9 +129,24 @@
 
 #include <gst/gst.h>
 
-GST_DEBUG_CATEGORY_STATIC (ges_asset_debug);
 #undef GST_CAT_DEFAULT
-#define GST_CAT_DEFAULT ges_asset_debug
+
+#ifndef GST_DISABLE_GST_DEBUG
+#define GST_CAT_DEFAULT ensure_debug_category()
+static GstDebugCategory *
+ensure_debug_category (void)
+{
+  static gsize cat_gonce = 0;
+
+  if (g_once_init_enter (&cat_gonce)) {
+    gsize cat_done = (gsize) _gst_debug_category_new ("ges-asset",
+        GST_DEBUG_FG_BLUE | GST_DEBUG_BOLD, "GES Asset");
+    g_once_init_leave (&cat_gonce, cat_done);
+  }
+
+  return (GstDebugCategory *) cat_gonce;
+}
+#endif /* GST_DISABLE_GST_DEBUG */
 
 enum
 {
@@ -429,6 +444,7 @@ ges_asset_set_property (GObject * object, guint property_id,
       ges_extractable_register_metas (asset->priv->extractable_type, asset);
       break;
     case PROP_ID:
+      /* G_PARAM_CONSTRUCT_ONLY */
       asset->priv->id = g_value_dup_string (value);
       break;
     case PROP_PROXY:
@@ -478,7 +494,8 @@ ges_asset_class_init (GESAssetClass * klass)
   _properties[PROP_TYPE] =
       g_param_spec_gtype ("extractable-type", "Extractable type",
       "The type of the Object that can be extracted out of the asset",
-      G_TYPE_OBJECT, G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE);
+      G_TYPE_OBJECT,
+      G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
   /**
    * GESAsset:id:
@@ -496,7 +513,7 @@ ges_asset_class_init (GESAssetClass * klass)
   _properties[PROP_ID] =
       g_param_spec_string ("id", "Identifier",
       "The unique identifier of the asset", NULL,
-      G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE);
+      G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
   /**
    * GESAsset:proxy:
@@ -510,7 +527,8 @@ ges_asset_class_init (GESAssetClass * klass)
    */
   _properties[PROP_PROXY] =
       g_param_spec_object ("proxy", "Proxy",
-      "The asset default proxy.", GES_TYPE_ASSET, G_PARAM_READWRITE);
+      "The asset default proxy.", GES_TYPE_ASSET,
+      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
   /**
    * GESAsset:proxy-target:
@@ -530,7 +548,8 @@ ges_asset_class_init (GESAssetClass * klass)
    */
   _properties[PROP_PROXY_TARGET] =
       g_param_spec_object ("proxy-target", "Proxy target",
-      "The target of a proxy asset.", GES_TYPE_ASSET, G_PARAM_READABLE);
+      "The target of a proxy asset.", GES_TYPE_ASSET,
+      G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_properties (object_class, PROP_LAST, _properties);
 
@@ -538,9 +557,6 @@ ges_asset_class_init (GESAssetClass * klass)
   klass->extract = ges_asset_extract_default;
   klass->request_id_update = ges_asset_request_id_update_default;
   klass->inform_proxy = NULL;
-
-  GST_DEBUG_CATEGORY_INIT (ges_asset_debug, "ges-asset",
-      GST_DEBUG_FG_BLUE | GST_DEBUG_BOLD, "GES Asset");
 }
 
 void
